"""fhs_enyaq_data - enyaq car data versions """

__version__ = "0.1.4"
__author__ = "Richard de Vos <rdevos72@gmail.com>"
__author_name__ = "Richard de Vos"
__author_email__ = "rdevos72@gmail.com"
__app_name__ = "fhs_enyaq_data"
__project_name__ = "fhs-enyaq-data"
__all__ = []
